<?php

namespace FiloBlu\FreeShippingOrderInfo\Console\Command;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class CriticalCommand
 * @package FiloBlu\Flow\Console\Command
 */
class FixOrderCommands extends Command
{
    /**
     * @var \Magento\Sales\Model\ResourceModel\Order\CollectionFactory
     */
    protected $_orderCollectionFactory;

    /**
     * @var \Magento\Framework\App\State
     */
    protected $_state;

    /**
     * @var \FiloBlu\FreeShippingOrderInfo\Helper\Order
     */
    protected $_orderHelper;

    /**
     * FixOrderCommands constructor.
     * @param \Magento\Framework\App\State $state
     * @param \Magento\Sales\Model\ResourceModel\Order\CollectionFactory $orderCollectionFactory
     * @param \FiloBlu\FreeShippingOrderInfo\Helper\Order $orderHelper
     */
    public function __construct(
        \Magento\Framework\App\State $state,
        \Magento\Sales\Model\ResourceModel\Order\CollectionFactory $orderCollectionFactory,
        \FiloBlu\FreeShippingOrderInfo\Helper\Order $orderHelper
    )
    {
        $this->_state = $state;
        $this->_orderCollectionFactory = $orderCollectionFactory;
        $this->_orderHelper = $orderHelper;

        parent::__construct();
    }

    /**
     *
     */
    protected function configure()
    {
        $this->setName('orders:freeshipping:fix')
            ->setDescription('Fix freeshipping infos');
    }

    /**
     * @param InputInterface $input
     * @param OutputInterface $output
     * @return int|null|void
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        try {
            $this->state->setAreaCode(\Magento\Framework\App\Area::AREA_ADMINHTML);
        } catch (\Exception $e) {
            $output->writeln("Areacode was already set, skipping!");
        }

        $collection = $this->_orderCollectionFactory->create()->addAttributeToSelect('*');

        /**
         * @var \Magento\Sales\Model\Order $order
         */
        foreach ($collection as $order) {
            if ($this->_orderHelper->updateFreeShippingFlag($order, true) === false) {
                continue;
            }

            $output->writeln('Order #' . $order->getIncrementId() . " - set freeshipping flag");
        }
    }

}